@@ -30,7 +30,8 @@ from sqlalchemy.orm.collections import attribute_mapped_collection
 
 
 __all__ = ['Store', 'Department', 'Subdepartment',
-           'Product', 'POS', 'PerpetualInventory']
+           'Product', 'POS', 'PerpetualInventory',
+           'Operator', 'Vendor', 'ReceivingDocument']
 
 
 Base = declarative_base()
@@ -983,3 +984,653 @@ PerpetualInventory.store = relationship(
     primaryjoin=Store.number == PerpetualInventory.store_number,
     foreign_keys=[Store.number],
     uselist=False)
+
+
+class Operator(Base):
+    """
+    Represents an user / employee.
+    """
+
+    __tablename__ = 'CLK_TAB'
+
+    order_number = Column(
+        'F1185', Integer(), primary_key=True, nullable=False)
+
+    record_status = Column(
+        'F1001', Integer(), nullable=True)
+
+    number = Column(
+        'F1126', Integer(), nullable=True)
+
+    vendor_id = Column(
+        'F27', String(length=14), nullable=True)
+
+    restriction_code = Column(
+        'F170', Integer(), nullable=True)
+
+    date_start = Column(
+        'F253', DateTime(), nullable=True)
+
+    batch_id = Column(
+        'F902', String(length=8), nullable=True)
+
+    target_id = Column(
+        'F1000', String(length=5), nullable=True)
+
+    store_number = Column(
+        'F1056', String(length=4), nullable=True)
+
+    short_name = Column(
+        'F1127', String(length=30), nullable=True)
+
+    secret_number = Column(
+        'F1141', Integer(), nullable=True)
+
+    restriction_level = Column(
+        'F1142', Integer(), nullable=True)
+
+    first_name = Column(
+        'F1143', String(length=30), nullable=True)
+
+    last_name = Column(
+        'F1144', String(length=30), nullable=True)
+
+    birth_date = Column(
+        'F1145', DateTime(), nullable=True)
+
+    language = Column(
+        'F1146', String(length=10), nullable=True)
+
+    customer_id = Column(
+        'F1148', String(length=14), nullable=True)
+
+    active_on_node = Column(
+        'F1176', String(length=3), nullable=True)
+
+    status = Column(
+        'F1552', String(length=4), nullable=True)
+
+    hiring_date = Column(
+        'F1553', DateTime(), nullable=True)
+
+    break_date = Column(
+        'F1554', DateTime(), nullable=True)
+
+    last_promotion_date = Column(
+        'F1555', DateTime(), nullable=True)
+
+    superior = Column(
+        'F1556', Integer(), nullable=True)
+
+    address_1 = Column(
+        'F1557', String(length=40), nullable=True)
+
+    address_2 = Column(
+        'F1558', String(length=40), nullable=True)
+
+    city = Column(
+        'F1559', String(length=40), nullable=True)
+
+    state = Column(
+        'F1560', String(length=20), nullable=True)
+
+    country = Column(
+        'F1561', String(length=20), nullable=True)
+
+    zipcode = Column(
+        'F1562', String(length=15), nullable=True)
+
+    phone_1 = Column(
+        'F1563', String(length=20), nullable=True)
+
+    phone_2 = Column(
+        'F1564', String(length=20), nullable=True)
+
+    insurance_number = Column(
+        'F1565', String(length=20), nullable=True)
+
+    holidays = Column(
+        'F1566', Float(), nullable=True)
+
+    payroll_table_link = Column(
+        'F1567', Integer(), nullable=True)
+
+    assigned_drawer_number = Column(
+        'F1568', Integer(), nullable=True)
+
+    department_number = Column(
+        'F1569', Integer(), nullable=True)
+
+    added_experience = Column(
+        'F1570', Float(), nullable=True)
+
+    email = Column(
+        'F1571', String(length=60), nullable=True)
+
+    job_description = Column(
+        'F1585', String(length=20), nullable=True)
+
+    gender = Column(
+        'F1586', String(length=4), nullable=True)
+
+    break_reason = Column(
+        'F1587', String(length=20), nullable=True)
+
+    civil_state = Column(
+        'F1588', String(length=4), nullable=True)
+
+    employee_number = Column(
+        'F1589', String(length=15), nullable=True)
+
+    note = Column(
+        'F1590', String(length=80), nullable=True)
+
+    store_responsible = Column(
+        'F1964', String(length=4), nullable=True)
+
+    clock_in_out = Column(
+        'F2587', DateTime(), nullable=True)
+
+    profit = Column(
+        'F2597', String(length=20), nullable=True)
+
+    show_filter = Column(
+        'F2692', String(length=1), nullable=True)
+
+    def __repr__(self):
+        return "Operator(order_number={0}, number={1})".format(
+            repr(self.order_number), repr(self.number))
+
+    def __str__(self):
+        return str(self.short_name or '')
+
+
+class Vendor(Base):
+    """
+    Represents a vendor.
+    """
+
+    __tablename__ = 'VENDOR_TAB'
+
+    id = Column(
+        'F27', String(length=14), primary_key=True, nullable=False)
+
+    batch_id = Column(
+        'F902', String(length=8), nullable=True)
+
+    record_status = Column(
+        'F1001', Integer(), nullable=True)
+
+    date_start = Column(
+        'F253', DateTime(), nullable=True)
+
+    name = Column(
+        'F334', String(length=40), nullable=True)
+
+    contact_name = Column(
+        'F335', String(length=40), nullable=True)
+
+    address_line_1 = Column(
+        'F336', String(length=40), nullable=True)
+
+    address_line_2 = Column(
+        'F337', String(length=40), nullable=True)
+
+    address_city = Column(
+        'F338', String(length=40), nullable=True)
+
+    address_state = Column(
+        'F339', String(length=15), nullable=True)
+
+    address_zipcode = Column(
+        'F340', String(length=15), nullable=True)
+
+    phone_voice = Column(
+        'F341', String(length=20), nullable=True)
+
+    phone_fax = Column(
+        'F342', String(length=15), nullable=True)
+
+    product_categories = Column(
+        'F343', String(length=30), nullable=True)
+
+    freight_broker_company = Column(
+        'F344', String(length=20), nullable=True)
+
+    fob_point = Column(
+        'F345', String(length=20), nullable=True)
+
+    limit = Column(
+        'F346', Float(), nullable=True)
+
+    special_discount_percent = Column(
+        'F347', Float(), nullable=True)
+
+    terms_days = Column(
+        'F348', Integer(), nullable=True)
+
+    terms_discount_percent = Column(
+        'F349', Float(), nullable=True)
+
+    duns_number = Column(
+        'F350', String(length=9), nullable=True)
+
+    supplier_location_number = Column(
+        'F351', String(length=6), nullable=True)
+
+    account = Column(
+        'F352', String(length=10), nullable=True)
+
+    deliver_monday = Column(
+        'F353', String(length=1), nullable=True)
+
+    deliver_tuesday = Column(
+        'F354', String(length=1), nullable=True)
+
+    deliver_wednesday = Column(
+        'F355', String(length=1), nullable=True)
+
+    deliver_thursday = Column(
+        'F356', String(length=1), nullable=True)
+
+    deliver_friday = Column(
+        'F357', String(length=1), nullable=True)
+
+    deliver_saturday = Column(
+        'F358', String(length=1), nullable=True)
+
+    deliver_sunday = Column(
+        'F359', String(length=1), nullable=True)
+
+    target_id = Column(
+        'F1000', String(length=5), nullable=True)
+
+    operator_responsible = Column(
+        'F1168', Integer(), nullable=True)
+
+    ship_id_number = Column(
+        'F1642', String(length=14), nullable=True)
+
+    freight_rate_weight = Column(
+        'F1654', Float(), nullable=True)
+
+    freight_rate_volume = Column(
+        'F1655', Float(), nullable=True)
+
+    term_description = Column(
+        'F1656', String(length=30), nullable=True)
+
+    back_order_days = Column(
+        'F1685', Integer(), nullable=True)
+
+    maintenance_operator_level = Column(
+        'F1759', Integer(), nullable=True)
+
+    minimum_cases = Column(
+        'F1760', Float(), nullable=True)
+
+    minimum_cubic = Column(
+        'F1761', Float(), nullable=True)
+
+    internal_comment = Column(
+        'F1779', String(length=120), nullable=True)
+
+    delivery_days = Column(
+        'F1793', Integer(), nullable=True)
+
+    delivery_cycle_days = Column(
+        'F1794', Integer(), nullable=True)
+
+    comment = Column(
+        'F1882', String(length=120), nullable=True)
+
+    minimum_weight = Column(
+        'F1883', Float(), nullable=True)
+
+    minimum_dollars = Column(
+        'F1884', Numeric(precision=8, scale=4), nullable=True)
+
+    buying_format = Column(
+        'F1887', String(length=2), nullable=True)
+
+    contact_2 = Column(
+        'F1889', String(length=40), nullable=True)
+
+    contact_2_phone = Column(
+        'F1890', String(length=20), nullable=True)
+
+    contact_2_fax = Column(
+        'F1891', String(length=15), nullable=True)
+
+    country = Column(
+        'F1948', String(length=30), nullable=True)
+
+    status = Column(
+        'F1949', String(length=6), nullable=True)
+
+    store_responsible = Column(
+        'F1964', String(length=4), nullable=True)
+
+    show_priority = Column(
+        'F1965', Integer(), nullable=True)
+
+    show_filter = Column(
+        'F1966', String(length=20), nullable=True)
+
+    profit = Column(
+        'F2597', String(length=20), nullable=True)
+
+    currency_code = Column(
+        'F2602', String(length=3), nullable=True)
+
+    email = Column(
+        'F2603', String(length=60), nullable=True)
+
+    invisible_on_pda = Column(
+        'F2658', String(length=1), nullable=True)
+
+    url = Column(
+        'F2660', String(length=250), nullable=True)
+
+    default_quantity = Column(
+        'F2666', Float(), nullable=True)
+
+    maximum_cases = Column(
+        'F2700', Float(), nullable=True)
+
+    maximum_cubic = Column(
+        'F2701', Float(), nullable=True)
+
+    maximum_weight = Column(
+        'F2702', Float(), nullable=True)
+
+    associated_tax_rates = Column(
+        'F2710', String(length=10), nullable=True)
+
+    def __repr__(self):
+        return "Vendor(id={0})".format(repr(self.id))
+
+    def __str__(self):
+        return str(self.name or '')
+    
+
+class ReceivingDocument(Base):
+    """
+    Represents a receiving document in any of its phases.
+
+    Although this model is named ``ReceivingDocument``, it can represent any of
+    the following:
+
+    * purchasing document
+    * receiving document
+    * billing document
+    * direct delivery document
+    """
+
+    __tablename__ = 'REC_HDR'
+
+    transaction_number = Column(
+        'F1032', Integer(), primary_key=True, nullable=False)
+
+    vendor_id = Column(
+        'F27', String(length=14), nullable=True)
+
+    order_date = Column(
+        'F76', DateTime(), nullable=True)
+
+    purchase_order_number = Column(
+        'F91', String(length=8), nullable=True)
+
+    date_start = Column(
+        'F253', DateTime(), nullable=True)
+
+    date_end = Column(
+        'F254', DateTime(), nullable=True)
+
+    vendor_name = Column(
+        'F334', String(length=40), nullable=True)
+
+    vendor_contact_name = Column(
+        'F335', String(length=40), nullable=True)
+
+    vendor_address_line_1 = Column(
+        'F336', String(length=40), nullable=True)
+
+    vendor_address_line_2 = Column(
+        'F337', String(length=40), nullable=True)
+
+    vendor_address_city = Column(
+        'F338', String(length=40), nullable=True)
+
+    vendor_address_state = Column(
+        'F339', String(length=15), nullable=True)
+
+    vendor_address_zipcode = Column(
+        'F340', String(length=15), nullable=True)
+
+    vendor_phone_voice = Column(
+        'F341', String(length=20), nullable=True)
+
+    vendor_phone_fax = Column(
+        'F342', String(length=15), nullable=True)
+
+    vendor_product_categories = Column(
+        'F343', String(length=30), nullable=True)
+
+    freight_broker_company = Column(
+        'F344', String(length=20), nullable=True)
+
+    fob_point = Column(
+        'F345', String(length=20), nullable=True)
+
+    vendor_limit = Column(
+        'F346', Float(), nullable=True)
+
+    special_discount_percent = Column(
+        'F347', Float(), nullable=True)
+
+    terms_days = Column(
+        'F348', Integer(), nullable=True)
+
+    terms_discount_percent = Column(
+        'F349', Float(), nullable=True)
+
+    vendor_account = Column(
+        'F352', String(length=10), nullable=True)
+
+    batch_id = Column(
+        'F902', String(length=8), nullable=True)
+
+    movement_start_time = Column(
+        'F1035', String(length=6), nullable=True)
+
+    movement_end_time = Column(
+        'F1036', String(length=6), nullable=True)
+
+    store_number = Column(
+        'F1056', String(length=4), nullable=True)
+
+    terminal_number = Column(
+        'F1057', String(length=4), nullable=True)
+
+    registration_mode = Column(
+        'F1067', String(length=7), nullable=True)
+
+    transaction_mode = Column(
+        'F1068', String(length=6), nullable=True)
+
+    line_number = Column(
+        'F1101', Integer(), nullable=True)
+
+    operator_number = Column(
+        'F1126', Integer(), nullable=True)
+
+    operator_short_name = Column(
+        'F1127', String(length=30), nullable=True)
+
+    customer_id = Column(
+        'F1148', String(length=14), nullable=True)
+
+    operator_responsible = Column(
+        'F1168', Integer(), nullable=True)
+
+    reference_number = Column(
+        'F1245', String(length=20), nullable=True)
+
+    delivery_date = Column(
+        'F1246', DateTime(), nullable=True)
+
+    transaction_note = Column(
+        'F1254', String(length=500), nullable=True)
+
+    batch_file_name = Column(
+        'F1255', String(length=40), nullable=True)
+
+    creation_date = Column(
+        'F1264', DateTime(), nullable=True)
+
+    ship_id_number = Column(
+        'F1642', String(length=14), nullable=True)
+
+    ship_name = Column(
+        'F1643', String(length=40), nullable=True)
+
+    ship_contact_name = Column(
+        'F1644', String(length=40), nullable=True)
+
+    ship_address_line_1 = Column(
+        'F1645', String(length=40), nullable=True)
+
+    ship_address_line_2 = Column(
+        'F1646', String(length=40), nullable=True)
+
+    ship_address_city = Column(
+        'F1647', String(length=40), nullable=True)
+
+    ship_address_state = Column(
+        'F1648', String(length=15), nullable=True)
+
+    ship_address_zipcode = Column(
+        'F1649', String(length=15), nullable=True)
+
+    ship_phone_voice = Column(
+        'F1650', String(length=15), nullable=True)
+
+    ship_phone_fax = Column(
+        'F1651', String(length=15), nullable=True)
+
+    ship_product_categories = Column(
+        'F1652', String(length=30), nullable=True)
+
+    shipping_date = Column(
+        'F1653', DateTime(), nullable=True)
+
+    freight_rate_weight = Column(
+        'F1654', Float(), nullable=True)
+
+    freight_rate_volume = Column(
+        'F1655', Float(), nullable=True)
+
+    vendor_term_description = Column(
+        'F1656', String(length=30), nullable=True)
+
+    back_order_days = Column(
+        'F1685', Integer(), nullable=True)
+
+    operator_order_printed = Column(
+        'F1686', Integer(), nullable=True)
+
+    operator_receipt_printed = Column(
+        'F1687', Integer(), nullable=True)
+
+    operator_invoice_printed = Column(
+        'F1688', Integer(), nullable=True)
+
+    operator_export_made = Column(
+        'F1689', Integer(), nullable=True)
+
+    shipping_note = Column(
+        'F1692', String(length=80), nullable=True)
+
+    operator_order_entered_id = Column(
+        'F1693', Integer(), nullable=True)
+
+    operator_receipt_confirm = Column(
+        'F1694', Integer(), nullable=True)
+
+    operator_invoice_entered = Column(
+        'F1695', Integer(), nullable=True)
+
+    operator_trucker = Column(
+        'F1696', Integer(), nullable=True)
+
+    minimum_cases = Column(
+        'F1760', Float(), nullable=True)
+
+    minimum_cubic = Column(
+        'F1761', Float(), nullable=True)
+
+    delivery_days = Column(
+        'F1793', Integer(), nullable=True)
+
+    minimum_weight = Column(
+        'F1883', Float(), nullable=True)
+
+    minimum_dollars = Column(
+        'F1884', Numeric(precision=8, scale=4), nullable=True)
+
+    buying_format = Column(
+        'F1887', String(length=2), nullable=True)
+
+    vendor_contact_2 = Column(
+        'F1889', String(length=40), nullable=True)
+
+    vendor_contact_2_phone = Column(
+        'F1890', String(length=20), nullable=True)
+
+    date_payable = Column(
+        'F2596', DateTime(), nullable=True)
+
+    currency_exchange_now = Column(
+        'F2598', Float(), nullable=True)
+
+    currency_exchange_order = Column(
+        'F2599', Float(), nullable=True)
+
+    operator_pickup_printed = Column(
+        'F2632', Integer(), nullable=True)
+
+    order_time = Column(
+        'F2655', String(length=6), nullable=True)
+
+    delivery_time = Column(
+        'F2656', String(length=6), nullable=True)
+
+    event_date = Column(
+        'F2657', DateTime(), nullable=True)
+
+    invisible_on_pda = Column(
+        'F2658', String(length=1), nullable=True)
+
+    document_subtype = Column(
+        'F2659', String(length=6), nullable=True)
+
+    associated_tax_rates = Column(
+        'F2710', String(length=10), nullable=True)
+
+    def __repr__(self):
+        return "ReceivingDocument(transaction_number={0})".format(
+            repr(self.transaction_number))
+
+
+ReceivingDocument.vendor = relationship(
+    Vendor,
+    primaryjoin=Vendor.id == ReceivingDocument.vendor_id,
+    foreign_keys=[Vendor.id],
+    uselist=False)
+
+ReceivingDocument.operator_order_entered = relationship(
+    Operator,
+    primaryjoin=Operator.number == ReceivingDocument.operator_order_entered_id,
+    foreign_keys=[Operator.number],
+    uselist=False)
